@@ -1,4 +1,5 @@
-use std::{collections::HashMap, cell::RefCell, sync::{Mutex, Arc}, borrow::BorrowMut};
+use std::{collections::HashMap, cell::RefCell, sync::{Mutex, Arc}};
+
 use crate::value::Value;
 
 /// # Cache 实现了trait store 它可以将数据存储到内部变量caches中
@@ -8,6 +9,8 @@ use crate::value::Value;
 /// let mut rq = Requests::new(&data).connect("https://www.qq.com", Headers::Default)
 /// '''
 pub trait Store {
+    type Item;
+
     fn pipes(&self, key: &str, result: Value);
     fn print(&self) ;
     fn print_json(&self);
@@ -15,20 +18,54 @@ pub trait Store {
     fn get(&self, key:&str) -> Value;
 }
 
-#[derive(Debug)]
+
+pub trait Item {
+    type Output;
+
+    fn build(x: Self::Output) -> Box<Self::Output> where Self: Sized { Box::new(x) }
+    
+    // fn clone(&self) -> Self::Output;
+}
+
+#[derive(Clone, Debug)]
+pub struct Person {
+    pub name: String,
+    pub age: u32,
+}
+
+impl Item for Person {
+    type Output = Person;
+
+    // fn clone(&self) -> Self::Output {
+    //     Person {
+    //         name: self.name.clone(),
+    //         age: self.age,
+    //     }
+    // }
+}
+
+
+
 pub struct Cache {
-    caches: Arc<Mutex<RefCell::<HashMap<String,Value>>>>
+    caches: Arc<Mutex<RefCell::<HashMap<String,Value>>>>,
 }
 
 impl Cache {
+
     pub fn new() -> Self {
-        Cache {caches: Arc::new(Mutex::new(RefCell::new(HashMap::new())))}
+        Cache {
+            caches: Arc::new(Mutex::new(RefCell::new(HashMap::new()))),
+        }
     }
 }
 
 
+
 impl Store for Cache  {
-    fn pipes(&self, key: &str, result: Value) {
+    type Item = Value;
+
+
+    fn pipes(&self, key: &str, result: Self::Item) {
         let caches = Arc::clone(&self.caches);
         let caches = caches.lock().unwrap();
         (*caches).borrow_mut().insert(key.to_string(), result);
@@ -61,21 +98,14 @@ impl Store for Cache  {
     }
 
     fn get(&self, key:&str) -> Value {
-        let mut vv = Value::NULL;
         for (k, v) in self.caches.lock().unwrap().borrow().iter() {
             if k == key {
-                match v {
-                    Value::STR(s) => vv = Value::STR(s.to_string()),
-                    Value::LIST(s) => vv = Value::LIST(
-                        s.iter().map(|x| x.to_owned()).collect::<Vec<String>>()
-                    ),
-                    Value::INT(i) => vv = Value::INT(*i),
-                    _ => (),
-                }
+                let data = serde_json::to_string(v).expect("not Serialize to string");
+                let result = serde_json::from_str::<Value>(data.as_str()).expect("not Deserialize to string");
+                return result;
             }
-            
         }
-        vv
+        Value::NULL
     }
 
-}
\ No newline at end of file
+}
