@@ -9,6 +9,7 @@ pub mod headers; // defined headers
 pub mod value;
 pub mod untils; // get data from store database
 
+
 pub use self::requests::Requests;
 pub use self::cache::Cache;
 pub use self::cache::Store;
@@ -19,3 +20,6 @@ pub use self::untils::tool::Tool;
 pub use select;
 pub use dbfile;
 pub use dbfile_derive;
+pub use postgres;
+pub use rusqlite;
+pub use regex;
